import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';
import { getPopupContainer } from '@vben/utils';

import { type FormSchemaGetter } from '#/adapter/form';
import { getDictOptions } from '#/utils/dict';
import { renderDict } from '#/utils/render';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'fixtureName',
    label: '工具名称'
  },
  {
    component: 'Input',
    fieldName: 'fixtureCode',
    label: '工具编码'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.EIMS_FIXTURE_STATUS)
    },
    fieldName: 'status',
    label: '工具状态'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.FIXTURE_BORROW_STATUS)
    },
    fieldName: 'borrowStatus',
    label: '借用状态'
  },
  {
    component: 'Input',
    fieldName: 'assetNo',
    label: '资产编号'
  },
  {
    component: 'Input',
    fieldName: 'modelNo',
    label: '工具型号'
  },
  {
    component: 'Input',
    fieldName: 'specNo',
    label: '工具规格'
  },
  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'borrowDept',
    label: '借用部门',
    // rules: 'selectRequired',
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'borrowUser',
    label: '借用人'
  },
  {
    component: 'Input',
    fieldName: 'madeIn',
    label: '制造商'
  },
  {
    component: 'RangePicker',
    fieldName: 'purchaseDate',
    label: '采购日期'
  },
  {
    component: 'RangePicker',
    fieldName: 'deployDate',
    label: '使用日期'
  }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '工具(治具)名称',
    field: 'fixtureName',
    minWidth: 140,
    fixed: 'left',
    slots: { default: 'fixtureName' }
  },

  {
    title: '状态',
    field: 'status',
    sortable: true,
    slots: {
      default: ({ row }) => {
        if (row.status === null || row.status === '') {
          return '';
        }
        return renderDict(row.status, DictEnum.EIMS_FIXTURE_STATUS);
      }
    },
    minWidth: 80,
    fixed: 'left'
  },
  {
    title: '借用状态',
    field: 'borrowStatus',
    sortable: true,
    slots: {
      default: ({ row }) => {
        if (row.borrowStatus === null || row.borrowStatus === '') {
          return '';
        }
        return renderDict(row.borrowStatus, DictEnum.FIXTURE_BORROW_STATUS);
      }
    },
    minWidth: 100,
    fixed: 'left'
  },
  {
    title: '类型',
    field: 'fixtureTypeName',
    minWidth: 100
  },
  {
    title: '资产编号',
    field: 'assetNo',
    sortable: true,
    minWidth: 140
  },
  {
    title: '借用人',
    field: 'borrowUserName',
    minWidth: 100
  },
  {
    title: '工具编码',
    field: 'fixtureCode',
    sortable: true,
    minWidth: 100
  },
  {
    title: '型号',
    field: 'modelNo',
    minWidth: 100
  },
  {
    title: '规格',
    field: 'specNo',
    minWidth: 100
  },
  {
    title: '制造商',
    field: 'madeIn',
    minWidth: 140
  },
  {
    title: '采购日期',
    field: 'purchaseDate',
    minWidth: 140
  },
  {
    title: '使用日期',
    field: 'deployDate',
    minWidth: 140
  },
  {
    title: '使用年限',
    field: 'serviceLife',
    minWidth: 100
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 200
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'id'
  },
  {
    component: 'TreeSelect',
    defaultValue: 0,
    fieldName: 'fixtureType',
    label: '工具类型',
    rules: 'selectRequired'
  },
  {
    component: 'Input',
    fieldName: 'fixtureName',
    label: '工具名称',
    rules: 'required'
  },
  {
    component: 'Input',
    fieldName: 'fixtureCode',
    label: '工具编码',
    rules: 'required'
  },
  {
    component: 'Input',
    fieldName: 'assetNo',
    label: '资产编号'
  },
  {
    component: 'Input',
    fieldName: 'modelNo',
    label: '型号'
  },
  {
    component: 'Input',
    fieldName: 'specNo',
    label: '规格'
  },
  {
    component: 'Input',
    fieldName: 'madeIn',
    label: '制造商'
  },
  {
    component: 'RadioGroup',
    componentProps: {
      buttonStyle: 'solid',
      options: getDictOptions(DictEnum.EIMS_FIXTURE_STATUS),
      optionType: 'button'
    },
    defaultValue: '0',
    fieldName: 'status',
    label: '状态'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      showTime: false,
      valueFormat: 'YYYY-MM-DD',
      getPopupContainer
    },
    fieldName: 'purchaseDate',
    label: '采购日期'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      showTime: false,
      valueFormat: 'YYYY-MM-DD',
      getPopupContainer
    },
    fieldName: 'deployDate',
    label: '使用日期'
  },
  {
    component: 'Input',
    fieldName: 'serviceLife',
    label: '使用年限'
  }
];
